@@ -1,10 +1,14 @@
 from .base import Expr
 from ..node import Node
-from spartan.dense import tile, distarray
+from spartan.array import tile, distarray
 import numpy as np
 
 class NdArrayExpr(Expr):
+  __metaclass__ = Node
   _members = ['_shape', 'dtype', 'tile_hint', 'combine_fn', 'reduce_fn']
+
+  def __str__(self):
+    return 'array(%s, %s)' % (self.shape, self.dtype)
   
   def visit(self, visitor):
     return NdArrayExpr(_shape=visitor.visit(self.shape),
